# Version 0.1.2 - Date : December 15, 2022
- Fixing errors.
- Reliable implementation of "used_subflows".
- Addition used_flows tests in the "test_io".
- Clear "used_subflows" function docstring. 

# Version 0.1.1 - Date : December 13, 2022
- First successful publish to PyPi.